
import { H4 } from "../components/Headings";
import { LoremMedium } from "../components/Loremipsum";
import { SupScrollLink } from "../components/ScrollLink";
import { Section, Subesction } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";



export const Safety: React.FC = () =>{
  useTabNavigation();
  
  return (
    <>
      <Section title="Role in iGem" id="Role">
        <LoremMedium/>
      </Section>
      <Section title="Check-Ins" id="Check-Ins">
        <div>
            <p>
            As part of our project to develop a prime-editing complex to correct the F508del mutation in cystic fibrosis, we place great emphasis on safety at all stages of research. Our final construct will be tested in primary cultures of epithelial cells obtained from nasal swabs, isolated from both patients and healthy individuals. from nasal swabs [link primär Kulturen]. To guarantee safety and ensure the highest level of precision and reliability of our results, we have introduced a series of carefully planned checkpoints during the experiments. These milestones allow for continuous monitoring, timely adjustments and validation at each critical stage. This ensures that potential issues are identified and addressed immediately, minimizing risk and improving the overall quality of the experimental results. [link zu den Experimenten] . iGEM places great emphasis on biosafety, ensuring that all projects adhere to strict safety standards. One of these measures is the iGEM White List, which includes organisms and parts that are pre-approved for use based on their safety profile. Any components or organisms not covered by this White List must be submitted as 'Check-ins' to the iGEM Safety Committee for approval. Check-ins are formal safety evaluations that allow the committee to assess the potential risks and ensure proper containment and handling procedures are in place. Although we used some parts and organisms that were not included on the White List, these were assessed as critical for our project and submitted as Check-ins to the iGEM Safety Committee. Furthermore, we were in active exchange with the committee throughout the process. The Check-ins provide a clear picture of the biosafety aspects of our project, reflecting our commitment to safety and compliance with iGEM standards. 
            The main safety measures we have implemented include: 
                Compliance with S1 conditions: Working in S1 laboratories ensures that only organisms in the lowest risk group are used, minimizing the risk to humans and the environment. 
                Sterile working practices: To avoid contamination, we have implemented strict hygiene measures, including the disinfection of work surfaces and the correct disposal of biological waste. 
                Controlled access: Access to laboratories was strictly regulated to ensure that only trained personnel worked with the genetically modified organisms and cell lines. 
                Documentation: All work steps, materials used and cell lines were carefully documented to ensure traceability and safety. 
                Safe handling of cell lines: The cell lines used for experiments were handled in accordance with the applicable safety regulations. This included regular checks for contamination and the safe storage and disposal of cell cultures. 
            </p>
            <H4 text="Checkin for the Prime-Editing Komplex "></H4>
            <p>
                Reverse transcriptase:  Reverse transcriptase plays a central role in prime editing by specifically inserting the correction as DNA at the inserted nick using an RNA template provided by pegRNA. The correction of the complementary DNA strand then takes place via the natural cell repair mechanisms.  This ensures an exact correction of the target sequence. We checked the reverse transcriptase to ensure it could perform precise genome editing without introducing unintended mutations. This was important to minimize the risk of off-target effects that could lead to unexpected or harmful consequences.
                pegRNA (Prime Editing Guide RNA): The pegRNA is a multifunctional RNA molecule that fulfils two essential tasks. Firstly, it serves as a standard guide RNA (gRNA) that binds specifically to the target DNA and thus marks the site of editing. Secondly, it contains an RNA template that encodes the desired DNA modification. This enables the precise integration of the genetic modifications at the target site. We evaluated pegRNA for its ability to specifically target and modified the intended DNA sequence. Ensuring its specificity was crucial to avoid the potential disruption of other genes.
                Nickase Cas9, CasX, Fanzor (SpuFz1): These modified nucleases are designed to cut only one strand of DNA. This leads to controlled and precise editing of the genome, as cutting only one strand minimizes the risk of unwanted double-strand breaks. CasX and Fanzor offer smaller alternatives to Cas9, which is particularly advantageous for use in cells or organisms where space and efficiency requirements in terms of the transport system are an issue. Fanzor, being a newly introduced endonuclease, was particularly scrutinized in our project to ensure its safety and effectiveness in different cellular contexts. 
            This prime-editing complex thus represents a precise and efficient method for gene editing. By combining these components, genetic modifications can be performed with minimal side effects
            </p>
            <H4 text="Checkin for Cloning"></H4>
            <p>
            For our  cloning experiments and the development of our prime editing complexes, we have amplified various plasmids in E. coli K-12 strains (DH5α,10-Beta) When working with microbial strains such as E. coli K-12 strains,  a it's important to consider potential risks associated with their use, even though they are generally regarded as safe in laboratory settings. All experiments were performed under strict S1 conditions, following all relevant safety protocols. Below you will find an overview of the E.coli K-12 strains for our cloning experiments, submitted by us as a checkin and the specific safety measures:
                E. coli K-12 strains (DH5α,10-Beta): Although these strains are non-pathogenic and have been modified to minimize the risk of spreading antibiotic resistance, there remains a low risk of horizontal gene transfer, where genetic material could be transferred to other microorganisms, potentially leading to the spread of resistance genes or other traits. If accidentally released into the environment, E. coli K-12 strains could potentially interact with native microbial communities. While they are typically outcompeted in natural environments, there's a remote possibility of ecological disruption, particularly in microenvironments where they could find a niche.While these strains are non-virulent, they still pose a minimal risk to humans, particularly immunocompromised individuals, through accidental ingestion or inhalation in a laboratory setting. 
            We submitted  the yeast strain Pichia pastoris (SMD1163) for the protein expression of Fanzor.
                Pichia pastoris (SMD1163): Pichia pastoris (SMD1163) is a widely used yeast strain for the expression of recombinant proteins. It is characterized by a methanol-inducible expression system (AOX1 promoter) and high cell growth rates, which makes it ideal for industrial applications. The strain can be easily genetically manipulated and can perform post-translational modifications, which supports correct protein production.
            When working with Pichia pastoris (SMD1163), various safety-relevant aspects must be observed. Although the organism is considered non-pathogenic and biologically safe (S1), skin contact and aerosol formation should be avoided to minimize the risk of infection or allergic reactions. When using genetically modified strains, it is important to follow the relevant GMO guidelines to prevent uncontrolled release. In addition, handling chemicals such as methanol requires special precautions as they are toxic and highly flammable. The disposal of cell cultures and waste must also be carried out in accordance with biosafety regulations, especially in the case of genetically modified organisms. 
            </p>
            <H4 text="Checkin for Testing in cell lines "></H4>
            <p>
            In our project, we paid attention to safety at every step, especially when working with specific cell lines [link Zellinien]. All experiments were performed under strict S1 conditions, following all relevant safety protocols. Given the sensitivity of the human cell lines we used, we placed great emphasis on controlled and well-designed workflows. All transfections were performed in our own transfection laboratory to ensure a high level of safety and compliance.  Below you will find an overview of the cell lines submitted by us as a checkin and the specific safety measures: 
            HEK293T-3HA-CFTR.
            The HEK293T-3HA-CFTR cell line is based on HEK293T cells expressing an additional tsA1609 allele of the SV40 large T antigen. This allele enables the replication of vectors containing the SV40 origin of replication. In addition to the native CFTR gene, which is not expressed in HEK cells, the HEK293T-3HA-CFTR cell line from Leuven carries another copy of the CFTR gene embedded in an expression cassette. This cassette contains a CMV promoter, which is derived from the human cytomegalovirus and is frequently used for the overexpression of genes in human cells. In addition, the cassette contains a puromycin resistance gene that is co-expressed with CFTR, allowing continuous selection of CFTR-expressing cells. 
                HEK293T-3HA-F508del-CFTR cell line: The HEK293T-3HA-F508del-CFTR cell line is a modified HEK293T cell line that carries the F508del mutation in the CFTR gene, which is responsible for the most common mutation in cystic fibrosis. This mutation leads to a defective CFTR protein that impairs the normal function of the chloride channel. The cell line is therefore ideal for studying the effects of this mutation and for evaluating potential therapies for cystic fibrosis. 
                CFBE41o- cell line: The CFBE41o- cell line, derived from the bronchial epithelial cells of a cystic fibrosis patient, is homozygous for the ΔF508-CFTR mutation and was essential for our cystic fibrosis research. . A reduced CFTR expression level is present. The cell line carries the CFTR defect and can therefore represent a patient with CF. The cell line is used to test our mechanism. These cells were immortalized with a replication-defective plasmid that retains their physiological properties.
            When working with the HEK293T and CFBE41o- cell lines, it’s important to consider the minimal risks associated with their use. While not harmful on their own, the genetic modifications in HEK293T cells require careful handling to prevent accidental release or exposure. These cells, engineered to overexpress CFTR, including the F508del mutation, necessitate strict safety measures like regular monitoring and proper waste disposal to comply with S1 laboratory standards. Similarly, CFBE41o- cells, due to their genetic modifications and disease relevance, require careful handling to avoid cross-contamination and ensure biosafety.
                Human nasal epithelial cells (hNECs): Human nasal epithelial cells (hNECs) were harvested using a nasal brush, a minimally invasive procedure, and cultured in air-liquid interface (ALI) cultures to model the airway epithelium. Human nasal epithelial cells (hNECs) were obtained using a nasal brush, a minimally invasive technique, and then cultured in air-liquid interface (ALI) cultures to model the airway epithelium. Using these primary cultures, derived from donors with airway diseases such as cystic fibrosis, we were able to simulate the in vivo conditions of such diseases.  
            Due to the sensitive nature of these primary human cells, we performed all experiments with hNECs in our S2 laboratory, where increased safety precautions were taken. This included strict safety controls, safe handling of samples and proper disposal of materials after testing. In particular, the hNECs underwent HHH (Triple H: HIV, HCV and HBV) testing to ensure that no contamination occurred during sample collection or experimentation. These tests included sterility testing, viability assessments and contamination testing to ensure the safety and integrity of both the samples and the laboratory environment. After a negative HHH test, the primary cultures can be treated as S1. In addition, the nasal epithelial cells were handled with the utmost care during collection, ensuring that all procedures were performed under sterile conditions to avoid any risk of contaminationFor this purpose, the intensive examination of ethical questions was fundamental and a constant companion of our project. The numerous results from the interviews in the areas of: Ethics, storage and training in the handling of samples have been summarized in a guideline for patient consent for Germany and are intended to provide iGEM teams with the scope, critical examination and observance of iGEM rules, international and national guidelines.  
            </p>
            <H4 text="Checkin for Delivery "></H4>
            <p>
            Our finished construct is designed to be delivered into the lung via an inhaler using lipid nanoparticles (LNPs). To be more spezific a selective organ-targeting (SORT)- LNPs were developed to deliver mRNA specifically to the lung, with special measures taken to increase biocompatibility and safety. Since the LNP composition is very specific and also differs from other formulas, we submitted the LNP as a checkin:
                LNP: These LNPs are then taken up by epithelial cells through endocytosis, releasing the construct into the cytosol. We carefully evaluated the potential risks, including unintended immune responses and the need for precise dosing to minimize side effects. In addition, we have conducted an in-depth analysis of the dual-use potential of our technology. Dual-use refers to the possibility that scientific advances can be used for both civilian and military purposes. Therefore, we have implemented strict safety protocols and ethical guidelines to ensure that our technology is used exclusively for peaceful and therapeutic applications. 
            </p>
        </div>
      </Section>
      <Section title="Our Lab" id="Our Lab">
        <LoremMedium/>
      </Section>
      <Section title="Biosafety" id="Biosafety">
        <Subesction title="Mechanism" id="Biosafety1">
          <LoremMedium/>
        </Subesction>
        <Subesction title="Delivery" id="Biosafety2">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="Biosecurity" id="Biosecurity">
        <Subesction title="Our Project" id="Biosecurity1">
          <LoremMedium/>
        </Subesction>
        <Subesction title="Risk Assesment" id="Biosecurity2">
          <LoremMedium/>
        </Subesction>
        <Subesction title="Managing Risks" id="Biosecurity3">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="Bioethics" id="Bioethics">
            <div>
                <p>
                    Bioethics is an interdisciplinary field of research that addresses ethical issues pertaining to the life sciences and medical research. It plays a pivotal role in contemporary research, particularly in projects that employ human samples or data. This is due to the fact that in these cases, the protection of the rights and dignity of the people involved is of the utmost importance <SupScrollLink label="1"/> (Chadwick_2012_Thiele_2001a). In order to ascertain the necessity for an ethics application, an interview was conducted with Eva-Maria Berens, the scientific director of the office of the Ethics Committee at Bielefeld University, as part of the current research project. Following a comprehensive review, it was concluded that an ethics application was not necessary for the specific research project. Nevertheless, a comprehensive patient consent form was developed in conjunction with Eva-Maria Berens to guarantee that the donors of their samples are adequately informed and provide their consent of their own volition. The document guarantees that all pertinent information regarding sample collection, utilisation and storage is provided in an intelligible format. Furthermore, an interview was conducted with Dr. Timm Weber, a representative of the biobank, to discuss the topic of bioethics in greater depth. During the course of the interviews, the ethical aspects of sample storage and utilisation within the biobank were discussed in detail. Particular attention was paid to the responsible handling and protection of the rights of the test subjects. The discussion of bioethics in both interviews emphasises the relevance of ethical principles for research and ensures that it is conducted in accordance with the highest ethical standards.
                </p>
            </div>
        <Subesction title="Gene Therapy" id="Bioethics1">
          <div>
                <p>
                The potential of gene therapy to treat genetic diseases is promising, but it is also associated with significant ethical issues. One of the principal challenges is ensuring the safety of the procedure and the potential for unforeseen long-term consequences. Such consequences may only become apparent years after the genetic intervention has taken place. The modification of the germline, which affects not only the individual but also future generations, is a particularly sensitive issue. This gives rise to the question of the extent to which the decisions made today will influence future generations without their consent, thereby jeopardising intergenerational justice <SupScrollLink label="2"/> (Rubeis_Steger_2018). Another ethical issue is the potential for misuse for eugenic purposes. While the current focus is on combating disease, future applications could be aimed at 'optimising' human traits, which could result in a worsening of social inequalities. Access to gene therapy is also a significant issue. High costs could limit access to wealthy population groups, which would reinforce existing inequalities <SupScrollLink label="3"/> (Ansah_2022_Cornetta_Patel_Wanjiku_Busakhala_2018). The issue of informed consent is also a key aspect. Many patients do not have the necessary knowledge to fully understand the complex risks, which raises ethical questions about their decision-making capacity. Overall, the debate around gene therapy highlights that ethical considerations such as safety, justice and patient rights need to be considered alongside scientific progress <SupScrollLink label="4"/> (Pugh_2020).  
                </p>
          </div>
        </Subesction>
        <Subesction title="Primary Cells" id="Bioethics2">
          <div>
            <H4 text="Introduction of primary cultures"></H4>
            <p>
            A primary culture is defined as a cell culture that is isolated directly from the tissue of an organism. In our case, the organism is human. The cells are then cultivated in a controlled environment, namely an S2 laboratory <SupScrollLink label="5"/> (Gstraunthaler_Lindl_2013). Primary cultures are a fundamental biomedical research tool, widely regarded as indispensable due to their capacity for realistic modelling of complex cell interactions. Primary cells are derived directly from the tissue of an organism and, as a consequence, they essentially retain their original properties. Consequently, they mirror the authentic conditions of the target tissue, which is vital for accurately assessing the impact of a therapeutic agent. In contrast, HEK cells represent transformed cell lines that exhibit physiological properties distinct from those of target cells in the human body. The effect of a therapeutic agent is typically limited to a specific cell type. The investigation of cell-specific effects and reactions of an active substance is feasible with the use of primary cells, as these possess the functional characteristics inherent to the cell type under consideration. Although HEK cells are relatively straightforward to cultivate, they are less representative of a number of tissue types and may activate other signalling pathways. The authenticity of the receptors and signalling pathways is guaranteed, as primary cells show the natural expression of receptors, ion channels and other cellular mechanisms. HEK cells are often genetically modified to express specific receptors, which can be useful for simple test systems. However, this does not reflect the complex environment of a real tissue. Given the sensitivity of primary cultures to environmental influences, thus resulting in higher risk of a contamination, it is imperative that researchers employ special safety measures to ensure the safety of themselves and the integrity of the cells. Primary cultures are employed extensively in the development of vaccines, cancer research and the investigation of basic cell processes. 
            </p>
            <H4 text="Ethics in work with primary cultures"></H4>
            <p>
                The term 'ethics' is used to describe the examination of moral principles that determine the behaviour of individuals or groups <SupScrollLink label="6"/> (Thiele_2001b). In a scientific context, the term 'ethics' encompasses the examination of the moral justifiability of actions and decisions, particularly with regard to the welfare of living beings and the responsible use of resources <SupScrollLink label="7"/> (Gethmann_2001). The isolation of primary cells from living organisms raises ethical questions, particularly in the case of human or animal tissue. In the context of research with animal primary cells, careful consideration must be given to the need for animal suffering and the potential benefits of the research <SupScrollLink label="8"/> (Kiani_Pheby_Henehan_Brown_Sieving_Sykora_Marks_Falsini_Capodicasa_Miertus_et al._2022). An ethical dilemma frequently arises from the fact that primary cells offer the most meaningful data from a biological standpoint, yet their production is associated with challenges. In this context, the necessity of primary cell cultures is called into question, and the promotion of alternative methods, such as artificially produced tissues or organoids, is advocated where feasible. It is of crucial importance to emphasize the necessity of ethical responsibility in the collection of primary cultures. It is of the utmost importance that the procedure is carried out with consideration for the rights, and particularly the well-being of the donor. The removal of cells or tissue must be medically justifiable and, moreover, ethically justifiable in every case. To this end, the potential for research use and the possible risks and burdens for the donor must be weighed against each other to ensure careful consideration. However, it is also particularly important to ensure that the donor is involved in the entire process and is able to make an informed decision. The purpose of the research, the use of the cells and possible consequences must also be made transparent at all times. 
                The obtaining of informed consent represents a fundamental aspect of ethical practice in the collection of primary cells. This process must encompass not only a formal consent procedure, but also the provision of comprehensive information to donors regarding the collection, utilisation and prospective future applications of the cells. The act of consent must be given freely and without undue influence, and donors must be fully aware of the consequences of their participation. Furthermore, donors must be granted the right to revoke their consent at any time without consequence. Prior to the collection of cells, a comprehensive discussion is held with the donor, during which all pertinent details are elucidated and any queries or concerns they may have, are addressed. This guarantees that the donor is adequately informed and is thus able to make an autonomous decision based on a comprehensive understanding of the procedure. 
                The protection of privacy and confidentiality is of paramount importance when working with primary cultures. Given that primary cultures are predominantly human tissue, they contain genetic information and other personal data that is sensitive and deserving of protection. It is therefore of great importance that the data is anonymized and kept strictly confidential in order to protect the identity of the donor. 
                Every person who has access to the data or samples must be obliged to comply with confidentiality standards. It must be ensured that all legal requirements for data protection are met, including compliance with data protection laws such as the GDPR in the EU. 
            </p>
            <H4 text="Safety aspects when working with primary cultures "></H4>
            <p>
            When working with primary cultures, there is a risk that the cells may be potentially infectious samples or contaminated. Therefore, it is of the utmost importance to adhere to strict biological safety measures in order to minimize the risk of exposure to dangerous pathogens. This includes the use of personal protective equipment, working in a biosafety cabinet and adhering to decontamination protocols.
            The overarching objective is the safeguarding of laboratory staff. This is achieved through the utilization of personal protective equipment, encompassing gloves, lab coats and safety goggles, in addition to the provision of training in pertinent safety protocols. 
            In order to prevent the release of potentially hazardous material, it is imperative that biological waste is disposed of in accordance with the established regulatory framework. The waste is subjected to rigorous sterilisation by autoclaving and subsequently rendered safe for disposal in the designated and labelled containers. 
            </p>
            <H4 text="Regulatory framework"></H4>
            <p>
            The field of primary culture research is subject to a plethora of legal regulations and guidelines at both the national and international levels. These regulations dictate the manner in which primary cultures may be obtained, used, and disposed of. They encompass regulations pertaining to the protection of donors, the secure handling of biological material, and the ethical responsibility towards the cells and their origin. It is of paramount importance that all laboratory practices align with these regulations. 
            </p>
          </div>
        </Subesction>
        <Subesction title="Consent and Guidelines" id="Bioethics3">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="References" id="References">
                <ol>
                  {/*<!-- Citation num 1--> */}
<li typeof="schema:WebPage" role="doc-biblioentry" property="schema:citation" id="desc-1">
	<span property="schema:author" typeof="schema:Organisation">
		<span property="schema:Name">Chadwick, Ruth F.</span>.
	</span>
	<span property="schema:name">Encyclopedia of applied ethics.</span>
	<i property="schema:publisher" typeof="schema:Organization">Academic Press</i>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2012">2012</time>).
</li>

{/*<!-- Citation num 2--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-2">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Rubeis, G.</span>;
		<span property="schema:Name"> Steger, F.</span>
	</span>
	<span property="schema:name">&nbsp;Risks and benefits of human germline genome editing: An ethical analysis. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Asian Bioethics Review</i>
	<b property="issueNumber" typeof="PublicationIssue"> 10</b>,&nbsp;
	<span property="schema:pageBegin">133–141</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2018">2018</time>).
	<a className="doi" href="https://doi.org/10.1007/s41649-018-0056-x"> doi: 10.1007/s41649-018-0056-x</a>
</li>

{/*<!-- Citation num 3--> */}
<li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-3">
	<span property="schema:author" typeof="schema:Person">
		<span property="schema:Name"> Ansah, E.</span>
	</span>
	<span property="schema:name">&nbsp;Ethical Challenges and Controversies in the Practice and Advancement of Gene Therapy. </span>
	<i property="schema:publisher" typeof="schema:Organization"> Advances in Cell and Gene Therapy</i>
	<b property="issueNumber" typeof="PublicationIssue"> 2022</b>,&nbsp;
	<span property="schema:pageBegin">1–5</span>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2022">2022</time>).
	<a className="doi" href="https://doi.org/10.1155/2022/1015996"> doi: 10.1155/2022/1015996</a>
</li>

{/*<!-- Citation num 4--> */}
<li typeof="schema:WebPage" role="doc-biblioentry" property="schema:citation" id="desc-4">
	<span property="schema:author" typeof="schema:Organisation">
		<span property="schema:Name">Pugh, Jonathan</span>.
	</span>
	<span property="schema:name">Autonomy, Rationality, and Contemporary Bioethics.</span>
	<i property="schema:publisher" typeof="schema:Organization">Oxford University PressOxford</i>
	(<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>).
</li>


                </ol>
                </Section>
    </>
  );
}
